package com.meas.system.service;

import java.util.List;

import com.meas.system.domain.MeasTransmissionRate;

/**
 * 透过率Service接口
 *
 * @author wgk
 * @date 2024-06-13
 */
public interface IMeasTransmissionRateService {
    /**
     * 查询透过率
     *
     * @param id 透过率主键
     * @return 透过率
     */
    public MeasTransmissionRate selectMeasTransmissionRateById(Long id);

    /**
     * 查询透过率列表
     *
     * @param measTransmissionRate 透过率
     * @return 透过率集合
     */
    public List<MeasTransmissionRate> selectMeasTransmissionRateList(MeasTransmissionRate measTransmissionRate);

    /**
     * 新增透过率
     *
     * @param measTransmissionRate 透过率
     * @return 结果
     */
    public MeasTransmissionRate insertMeasTransmissionRate(MeasTransmissionRate measTransmissionRate);

    /**
     * 修改透过率
     *
     * @param measTransmissionRate 透过率
     * @return 结果
     */
    public int updateMeasTransmissionRate(MeasTransmissionRate measTransmissionRate);

    /**
     * 批量删除透过率
     *
     * @param ids 需要删除的透过率主键集合
     * @return 结果
     */
    public int deleteMeasTransmissionRateByIds(Long[] ids);

    /**
     * 删除透过率信息
     *
     * @param id 透过率主键
     * @return 结果
     */
    public int deleteMeasTransmissionRateById(Long id);

    MeasTransmissionRate selectResultsByEnvDataId(Long envDataId);
}
